
# Example: test issue number 1

*[ribbity-org/ribbity-test-repo#1](https://github.com/ribbity-org/ribbity-test-repo/issues/1)*

---

<!--
---
frontpage = false # should it show up on front page?
priority = 999 # default priority 999 => in with all the rest :). 1 pushes it to top, etc.
---
-->

this is a test!


